Philosophy Gift Shop Science Art Prints & Clothing
Description: The Philosophy Shop 'The Gift of Truth excels all other Gifts' (Buddha). Unique online shop & gallery of famous people & paintings with intelligent quotes. Smart shopping for thoughtful gifts. Philosopher's portraits (ancient Greek, Indian & western philosophy), physics, science / scientists, mathematics, religion & morality, politicians / politics, education & school / teaching, evolution, sexuality, motivational / inspirational, music & classical composers, women & feminism / famous feminists, renaissance & impressionist fine art prints / artists, metaphysical poets, books & writers / authors, stupid humor. Products include posters, t-shirts, men's & women's clothing, apparel, 2010 calendars, journals, postcards, greeting cards, political buttons (badges / pins), mugs & steins, mouse pads, caps & hats, etc.
Keywords: Philosophy, Shop, Gift, Idea, Artist, Images, Products, Ancient, Greek, Indian, Chinese, Western, Education, Religion, Life, Science, Quote, Fine, Art, Prints, Posters, Calendars, Cards, Journals, Clothes, Men's, Women's, Clothing, T-Shirts, Apparel,cafepress

- Cart & Checkout
- Help
- Order Status
- Shop Home
- Currency:

Comment with Facebook Connect
Google Friend
Twitter / Tweet
@Philosophy_Shop
Share |
### Products
Large Posters Small Posters Mini Poster Prints Framed Poster Panel Prints 2010 Wall Calendars Journals / Diaries Postcards Greeting Cards Mousepads Bumper Stickers Coffee Cups, Mugs & Beer Steins Wall / Time Clocks Buttons / Badges Fridge Magnets Jewelry Box & Coasters Unique Custom Printed Tees Men's Women's White T-Shirts Men's Women's Black T-Shirts Longsleeve T Shirts Hooded Sweatshirts Women's Long Sleeve Clothing Tight Sexy Ladies Clothes Men's & Women's Boxer Shorts Women's Intimate Lingerie, Erotic Thongs Cotton Canvas Printed Tote Bag & Messenger Bags Children / Infant / Kids Clothes Printed Kitchen Chef BBQ Cooking Aprons Baseball Caps & Trucker Hats Dog Clothes

### Subjects
Ancient Greek Philosophy
Chinese Indian Metaphysics
Western Philosophy
20th Century Philosophers
Physics & Science Quotes
Scientists & Inventors
Famous Mathematicians
God Religion Morality
Famous Leader Politics
Education Educational
Evolution Life Nature
Motivational Inspirational
Metaphysical Poets
Literature Books Authors
Musicians Composers
Women Feminism Art
Renaissance Fine Art
Satire Humor Funny Jokes
Philosophy Shop Philosophy Website
Newsletter

The Philosophy Gift Shop
'The Gift of Truth Excels all Other Gifts' (Buddha)
Hello and welcome to the Philosophy Shop. We have a beautiful gallery of famous portraits and fine art prints with profound quotes from many of the greatest minds of human history - making it simple and easy to find artful intelligent gifts for friends and family (and yourself of course!).
We have purchased a variety of things (posters, journals, calendars, caps, t-shirts, buttons, coffee mugs, etc.) and can confirm their high quality. But most importantly, the daily experience of seeing these portraits and words of wisdom is a cheerful reminder of the more noble and beautiful aspects of our human nature & creativity.
So stand out from the crowd (and get some interesting comments!) with our cool collection of clothing, prints and apparel!
Hope you enjoy browsing around. Cheers,
Karene Jade Howie

Ancient Greek Philosophy Ancient Greek Philosopher's Portraits and Quotes. Thales, Anaximander, Anaximenes, Heraclitus, Pythagoras, Parmenides, Socrates, Plato, Aristotle, Hypatia, Epicurus. |
Eastern Philosophy: Chinese & Indian Philosophers Portraits with Quotes from Ancient Indian and Chinese (Eastern) Philosophy. Confucius, Lao Tzu, Buddha, Mahatma Gandhi, Lama (Tibet) Hinduism, Buddhism, Taoism. |
Western Philosophy Our favourite Philosophers from the 15th to 20th Century. de Montaigne, Hobbes, Descartes, Leibniz, Spinoza, Berkeley, Hume, Kant, Schopenhauer, Nietzsche, ...
20th Century Philosophy / Philosophers Contemporary Philosophy Quotes from the Twentieth Century. Albert Camus, Noam Chomsky, Jacques Derrida, Michel Foucault, William James, Karl Popper, Bertrand Russell, Ludwig Wittgenstein, ... |
Physics: Quantum Theory, Relativity, Cosmology Famous Physicists Quotes and Portraits. From Newton's Mechanics to Quantum Physics, Einstein's Theory of Relativity, Cosmology. |
Mathematics / Famous Mathematicians Portraits and Quotes from some Famous Mathematicians. Euclid, Isaac Newton, Gottfried Leibniz, Blaise Pascal, Kurt Godel, Albert Einstein, ...
Famous Scientists Inventors Explorers Selection of Quotes and Portraits of Famous Scientists, Inventors and Explorers. Archimedes, Christopher Columbus, Alexander Graham Bell, Thomas Edison, Nikola Tesla, ... |
Theology: On God Religion Morality Theology Quotes on God Religion and Morality. Aristotle, Cicero, Jesus Christ, Thomas Aquinas, Francis Bacon, Leo Tolstoy, Albert Einstein, ... |
Famous Leaders: Presidents Politicians Emperors Profound quotes from Famous Presidents and Politicians: US Presidents (United States of America), British Prime Ministers, Roman Emperors etc. On Democracy, Communism, Terrorism, War, Liberty, Freedom
Famous Quotes on Education, Educational Philosophy Famous philosopher's Portraits and Quotes on the importance of Education, both for the individual and collective Society. Socrates, Plato, Aristotle, Montaigne, Rousseau, Bronte, Montessori, Steiner. |
Nature Environment Evolution Ecology Portraits and Quotes on Nature, Evolution and Ecology from famous Environmentalists. Charles Darwin, Thomas Huxley, Herbert Spencer, Rachel Carson, ... |
Motivational / Inspirational Quotes Some inspiring Motivational & Inspirational Quotes. Wisdom from famous philosophers Socrates, Plato, Aristotle, Edmund Burke, Winston Churchill, Mahatma Gandhi, Martin Luther King, ...
Famous Poets Metaphysical Poetry Quotes from Famous Poems / Metaphysical Poetry. Charles Baudelaire, Samuel Taylor Coleridge, Percy Bysshe Shelley, William Wordsworth, ... |
Literature: Famous Books & Authors Literature / Books: Portraits and Quotes from some Famous Authors. Emily & Charlotte Bronte, George Orwell, Edgar Allen Poe, William Shakespeare, Mary Shelley, Voltaire, Oscar Wilde, ... |
Love Sex Human Sexuality Quotes on Erotic Art Evolutionary Philosophy of Love, Sex, & Human Sexuality quotes printed on Renaissance, Impressionist Erotic Art Nudes & Vintage Erotica Fine Art Prints. Cultivating the Beauty of the Human Mind & Body
Famous Musicians Classical Composers Portraits and Quotes from Famous Musicians and Classical Composers. Bach, Beethoven, Handel, Mozart, Wagner. |
Famous Women: Philosophy Science Feminism Art Portraits and Quotes from Famous Women: Philosophers, Scientists, Feminists, Artists. Sappho, Hypatia, Cleopatra, Wollstonecraft, Shelly, Curie, Nin, de Beauvoir, Arendt. |
Fine Art Prints: Renaissance Impressionist Erotic "Art is a re-creation of reality according to an artist's metaphysical judgments. An artist recreates those aspects of reality which represent his fundamental view of man's nature." (Ayn Rand)
Adult Humor & Funny Jokes: Political, Twisted Humor to brighten your day. "A sense of humour is needed armour. Joy in one's heart and some laughter on one's lips is a sign that the person down deep has a pretty good grasp of life." (Hugh Sidey) |
Large Posters Collection of our Favourite Large Poster Prints. An eclectic mix of philosophy, science and fine art paintings, portraits and famous quotes. |
Poster Prints: Small A thoughtful collection of our favourite Small Posters. Custom Fine Art Prints & Quotes on Philosophy, Physics, Religion, Education, Art, Politics and more.
Mini Posters Unique selection of our favourite Mini Poster Prints. Pictures, Portraits & Quotes from famous Philosophers, Scientists, Artists, Politicians & Free Thinkers. |
Framed Posters Elegant Framed Prints for your home or office. Browse our unique selection of our favourite Framed Posters. Famous portraits and quotes on Philosophy, Life, the Universe and much more. |
2010 Wall Calendars / Calendar Prints Collection of our Favourite 2010 Wall Calendars / Calendar Prints selected from each of the main Gift Shop Subject Sections.
Creative Writing Journal / Diary Collection of our favourite creative writing Journals / Diaries selected from each of the main Gift Shop Subject Sections. |
Postcards / Post Cards Collection of our Favourite Postcards selected from each of the main Gift Shop Sections. |
Greeting Cards Collection of our Favourite Greeting Cards selected from each of the main Gift Shop Subject Sections.
Mouse Pads: Custom Printed Photos Quotations Selection of our favourite Mouse Pads. Make working on the computer more fun with our cool collection of custom printed mousepads with famous portraits, fine art photos and profound quotations. |
Bumper Stickers: Rectangular Collection of our favourite Bumper Stickers (rectangular) selected from each of the main Gift Shop Subject Sections. |
Coffee Cups, Mugs and Beer Steins Cool collection of custom printed Coffee Cups, Mugs and Beer Steins. Great Mugs for steaming hot black coffee or a sparkling Stein of your favourite German Pilsner beer. Enjoy!
Wall Clocks / Time Clock Collection of our favourite Wall Clocks / Time Clocks selected from each of the main Gift Shop Subject Sections. |
Unique Custom Buttons / Badges / Pins Say something interesting with our unique collection of custom printed Buttons / Badges / Pins selected from each of the main Gift Shop Subject Sections. |
Magnets: Refrigerator / Fridge Magnet Collection of our favourite Refrigerator / Fridge Magnets (rectangular) selected from each of the main Gift Shop Subject Sections.
Tile Drink Coaster & Fashion Gift Jewelry Box Custom Printed Tile Coaster & Jewelry Box. Collection of our favourite decorative Tile Drink Coasters and Fine Art Fashion Jewelry Boxes (Framed Tile Box) selected from each of the main Gift Shop |
T-Shirts: Men's Women's Unique Custom Printed Tees Selection of our Unique Custom Printed T Shirts including White, Ash Grey, Golf Shirt, Men's Sleeveless Tee, Organic Cotton Tee & Value T-Shirts. |
Black Tee's: Custom Men's & Women's Black T-Shirts Collection of our Favorite Black Tee's for Men and Women. Enjoy our cool and unique range of custom printed Black T-Shirts.
Men's Women's Unique Custom Printed White T-Shirts Selection of our Unique Custom Printed White T-Shirts for Men & Women. |
Longsleeve T-Shirts & Hooded Sweatshirts Keep warm in cool clothes. See our selection of Unique Custom Printed long sleeve T-Shirts, Sweatshirts and Hooded Sweatshirts with an eclectic mix of images and quotes. |
Women's Clothes: Tight & Sexy Longsleeve Clothing Women's Longsleeve Clothing. Show of your curves with these tight fitting and sexy Womens Clothes! Jr Hoodie, Raglan Hoodie, Jr Raglan and Ladies Tracksuit.
Women's Clothing: Tight & Sexy Ladies Clothes For Smutty Sensual Women's Clothing that hugs your body most deliciously! See our flattering tight fitting sexy ladies clothes. Baby Doll T-Shirts, Cap Sleeves, Women's T-Shirts, Tank Tops, Jr Spaghet |
Underwear: Mens & Womens Boxer Shorts (Boxers) Kinky selection of Mens and Womens custom printed Boxer Shorts (White 100% Cotton Boxers for Men & Women). Super comfy erotic underwear for sleeping or play-time. |
Hot Exotic Lingerie: Sexy Thongs / Erotic G-String Gorgeous selection of custom exotic lingerie for women and girls. Our sexy erotic Thongs are comfy, unique and look hot! Surprise your lover or simply enjoy your secret philosophical lingerie.
Custom Printed Canvas Tote Bag, Messenger Bags Custom Printed Canvas Tote Bags and Colorful Polyester Messenger Bag. Great for shopping, students to carry their books (or your goodies to the beach / picnic) or as a nice gift. |
Children's Clothing: Infant / Kids Clothes Children's Clothing: Treat your child to some cool intellectual clothes. Bib, Infant Creeper, Kids Baseball Jersey, Kids Hoodie, Sweatshirt, T-Shirt and Infant / Toddler Tees. |
Chef's Apron: Custom Barbecue (BBQ) Kitchen Aprons Keep clean in the kitchen or be a cool chef at the Barbecue (BBQ) with one of our custom printed BBQ Aprons.
White & Black Baseball Caps & Truck Hats Cool Caps and Hats to protect you from the sun (and bad hair days!). White & Black Baseball Caps & Truck / Trucker Hats. |
Pets / Animals Dog Coats A nice gift for Man's (and Woman's!) best friend - your Dog! Cool Dog Coats that will make your Dog stand out in the crowd! |
Christmas Cards & Gifts Renaissance and Vintage Erotic Fine Art Christmas Cards & Gifts. Celebrate Christmas with some intelligent philosophy and poetry on the beauty / miracle of life.
Philosophy Gift Shop Site Map The Site Map has a complete list of all 500 Product pages in the Philosophy Gift Shop. We hope you enjoy browsing around!

Facebook Connect

Google Friend Connect

Twitter
@Philosophy_Shop

### Philosophy Shop Tweets

### About Cafepress: Website Details / Customer Service & Help

ABOUT CAFEPRESS: Cafepress are a print on demand online shop. As of November 2009 there are over 6 million members (shopkeepers who create their own shops & products) and 40 million products! The website is in the top 1000 websites on the internet and gets around one million visitors each day. Because products are print on demand they are more expensive than mass produced goods, however, you have the advantage of purchasing unique custom made products that are not found anywhere else (this is particularly true for our philosophy shop). Cafepress ships products world wide (we live in Australia and have bought numerous items without any problems) and they have a thirty day full refund so it is a safe place to purchase some pretty cool gifts / presents (for yourself or others!).

Order by Phone 1-877-809-1659 (30 Day Refund - Satisfaction Guaranteed)

CUSTOMER SERVICE: For help with: Cafepress Sales - Where's My Stuff - Track your Recent Orders - View or Change your Order - Shipping and Returns - Shipping Rates - Make a Return or Exchange - Questions and Order by Phone 1-877-809-1659 - Satisfaction Guaranteed.

Philosophy Shop: Famous Portraits and Quotes on Posters, Tshirts, Clothing, Apparel. is UpFront

ABOUT YOUR SHOP KEEPER: KARENE HOWIE My partner (philosopher Geoff Haselhurst) and I are building a large philosophy website which is the source (and inspiration) for most of the Philosophy images and quotes in this shop. Below are some of our favourite philosophers / quotes and links to relevant pages of our website. Philosophy (which is ultimately about Wisdom from Truth and Reality) is important to our world (all proceeds from this shop are used to promote our work on Philosophy). Thus we also hope that you find our philosophy website interesting! Cheers, Karene. (August, 2010)

The Most Simple Science Theory of Physical Reality.
Philosophy Physics Metaphysics of Space & the Wave Structure of Matter (WSM).

Simple Science | Metaphysics Reality | Einstein's Relativity | Quantum Physics | Cosmology Universe | Philosophy Truth | Evolution Utopia | Theology Morality | Philosophy Sexuality | Human Health Nutrition Diet

### Copyright 2005 - 2010: All Rights Reserved
The Philosophy Shop averages around 2,500 visitors each day (6,000 page views). We are one of the Top Shops at Cafepress (out of about 6 million shops).

This shop is powered by CafePress Inc. Copyright © 1999-
CafePress.com. All rights reserved.
Privacy Policy | Trademark & Copyright Information
Non-US currency rates are updated daily and may fluctuate.